[][src]Macro const_random::const_random

macro_rules! const_random {
    (u8) => { ... };
    (u16) => { ... };
    (u32) => { ... };
    (u64) => { ... };
    (u128) => { ... };
}

Random constants

Allows you to insert random constants into your code that will be auto-generated at compile time. A new value will be generated every time the relevent file is re-built.

Example

#![feature(proc_macro_hygiene)]
use const_random::const_random  ;
const MY_RANDOM_NUMBER: u32 = const_random!(u32);

Note that the #![feature(proc_macro_hygiene)] must be enabled on your crate for the macro to work.

The following types are supported u8, u16, u32, u64, and u128